@@ -40,8 +40,7 @@ compile theRunMode text templates tabs mytitle mylanguage formulas b
            UserTemplateFile _ -> return
                                    (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
                                       tabs formulas)
-           HTML -> do
-                    return
+           HTML -> return
                      (run b mylanguage mytitle (printPrepareTree (parseit minparsers text)) (printPrepareTree (parseit minparsers text))
                         (hostname . fullUrl $ st)
                         templates
@@ -52,9 +51,9 @@ compile theRunMode text templates tabs mytitle mylanguage formulas b
                         (hostname . fullUrl $ st)
                         templates
                         tabs formulas)
-           ExpandedTemplates -> return
-                                    (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
-                                      tabs formulas)
+           ExpandedTemplates -> do return 
+                                      (run b mylanguage mytitle (parseit parsers text) (parseit parsers text) (hostname . fullUrl $ st) templates
+                                        tabs formulas)
  
 {-DHUN| pathname of the temporary directory of the compiler |DHUN-}
  
