@@ -1,8 +1,8 @@
 module HtmlRenderer where
 import MediaWikiParseTree
 import MyState
-import qualified Data.Map as Map
-import Data.Map (Map)
+import qualified Data.Map.Strict as Map
+import Data.Map.Strict (Map)
 import Control.Monad.Trans.State
        (State, state, runState, put, get)
 import LatexRenderer
